Twitter to Discord Webhook
======
[![GitHub](https://img.shields.io/github/license/mashape/apistatus.svg)](https://raw.githubusercontent.com/poipoii/twitter2discord/master/LICENSE)
[![Build Status](https://travis-ci.org/poipoii/twitter2discord.svg?branch=master)](https://travis-ci.org/poipoii/twitter2discord)
[![Latest PyPI version](https://img.shields.io/pypi/v/twitter2discord.svg)](https://pypi.python.org/pypi/twitter2discord/)
[![Maintainability](https://api.codeclimate.com/v1/badges/f5a26f52fa0ee8b4d1a3/maintainability)](https://codeclimate.com/github/poipoii/twitter2discord/maintainability)
[![Coverage Status](https://coveralls.io/repos/github/poipoii/twitter2discord/badge.svg?branch=master)](https://coveralls.io/github/poipoii/twitter2discord?branch=master)


Installation
------------

### From PyPI with `pip`

```sh
$ pip3 install twitter2discord
```